## Internationalization

Day.js has great support for internationalization.

But none of them will be included in your build unless you use that.

By default, Day.js comes with English (United States) locale.

You can load multiple locales and switch between them easily.

[List of supported locales](../../src/locale)

You are super welcome to add a locale by opening a pull request :+1:

## API

#### Changing locale globally

* Returns locale string

```js
import 'dayjs/locale/es'
import de from 'dayjs/locale/de'
dayjs.locale('es') // use loaded locale globally
dayjs.locale('de-german', de) // use locale and update default name string
const customizedLocaleObject = { ... } // More details can be found in Customize section below.
dayjs.locale(customizedLocaleObject) // use customize locale
```

* Changing the global locale doesn't affect existing instances.

#### Changing locales locally

* Returns CURRENT `Dayjs` object.

Exactly the same as `dayjs#locale`, but only use locale in a specific instance.

```js
import 'dayjs/locale/es'
dayjs().locale('es').format() // use loaded locale locally
dayjs('2018-4-28', { locale: es } // through constructor
```

#### Changing locales in API call

Check API documents for more details.

```js
import 'dayjs/locale/es'
dayjs('2018-4-28').format(format, es) // use locale in this API call only
```

## Installation

* Via NPM:

```javascript
import 'dayjs/locale/es' // load on demand
// require('dayjs/locale/es') // CommonJS
// import locale_es from 'dayjs/locale/es' -> load and get locale_es locale object

dayjs.locale('es') // use locale globally
dayjs().locale('es').format() // use locale in a specific instance
```

* Via CDN:
```html
<script src="https://unpkg.com/dayjs"></script>
<!-- Load locale as window.dayjs_locale_NAME -->
<script src="https://unpkg.com/dayjs/locale/zh-cn"></script>
<script>
  dayjs.locale('zh-cn');
  dayjs().locale('zh-cn').format()
  // get locale object
  var customLocale = window.dayjs_locale_zh_cn // zh-cn -> zh_cn
</script>
```

## Customize

You could create your own locale.

Feel free to open a pull request to share your locale.

Template of a Day.js locale Object.
```javascript
const localeObject = {
  name: 'es', // name String
  weekdays: 'Domingo_Lunes ...'.split('_'), // weekdays Array
  months: 'Enero_Febrero ... '.split('_'), // months Array
  ordinal: n => `${n}º` // ordinal Function (number) => return number + output
}
```

Template of a Day.js locale file.
```javascript
import dayjs from 'dayjs'

const locale = { ... } // Your Day.js locale Object.

dayjs.locale(locale, null, true) // load locale for later use

export default locale
```