## 国际化 I18n

Day.js 支持国际化

但除非手动加载，多国语言默认是不会被打包到工程里的

Day.js 内置的是英语（English - United States）语言

您可以加载多个其他语言并自由切换

[支持的语言列表](../../src/locale)

欢迎给我们提交 Pull Request 来增加新的语言

## API

#### 改变全局语言

* 返回使用语言的字符串

```js
import 'dayjs/locale/zh-cn'
import de from 'dayjs/locale/de'
dayjs.locale('zh-cn') // 全局使用简体中文
dayjs.locale('de-german', de) // 使用并更新语言包的名字
const customizedLocaleObject = { ... } // 更多细节请参考下方的自定义语言对象
dayjs.locale(customizedLocaleObject) // 使用自定义语言
```

* 改变全局语言并不会影响在此之前生成的实例

#### Changing locales locally

* Returns CURRENT `Dayjs` object.

Exactly the same as `dayjs#locale`, but only use locale in a specific instance.

```js
import 'dayjs/locale/es'
dayjs().locale('es').format() // use loaded locale locally
dayjs('2018-4-28', { locale: es } // through constructor
```

#### Changing locales in API call

Check API documents for more details.

```js
import 'dayjs/locale/es'
dayjs('2018-4-28').format(format, es) // use locale in this API call only
```

## Installation

* Via NPM:

```javascript
import 'dayjs/locale/es' // load on demand
// require('dayjs/locale/es') // CommonJS
// import locale_es from 'dayjs/locale/es' -> load and get locale_es locale object

dayjs.locale('es') // use locale globally
dayjs().locale('es').format() // use locale in a specific instance
```

* Via CDN:
```html
<script src="https://unpkg.com/dayjs"></script>
<!-- Load locale as window.dayjs_locale_NAME -->
<script src="https://unpkg.com/dayjs/locale/zh-cn"></script>
<script>
  dayjs.locale('zh-cn');
  dayjs().locale('zh-cn').format()
  // get locale object
  var customLocale = window.dayjs_locale_zh_cn // zh-cn -> zh_cn
</script>
```

## Customize

You could create your own locale.

Feel free to open a pull request to share your locale.

Template of a Day.js locale Object.
```javascript
const localeObject = {
  name: 'es', // name String
  weekdays: 'Domingo_Lunes ...'.split('_'), // weekdays Array
  months: 'Enero_Febrero ... '.split('_'), // months Array
  ordinal: n => `${n}º` // ordinal Function (number) => return number + output
}
```

Template of a Day.js locale file.
```javascript
import dayjs from 'dayjs'

const locale = { ... } // Your Day.js locale Object.

dayjs.locale(locale, null, true) // load locale for later use

export default locale
```